==> manim-chemistry-0.1.0.tar.gz: manim-chemistry-0.1.0/TODO.md <==
# Necessary development to make this a decent work

This lists things that should be added in the near future to make this library useful and not just a random piece of garbage. Probably will grow with the project.

* [ ] Improve molecule creation.
* [ ] 2d atom should use element as a basis like 3d atom does.
* [ ] 3d should be separate files like 2d.
* [ ] Create actual code for the 3d bonds and not simply use the yoinked logic.
* [ ] Use a base class for both 2d and 3d and then add functionality. In the end, the main differences are the used objects.
* [ ] Add an option for coloring to 2d molecules (right after using element for 2d atoms this can be easily implemented).
* [ ] For God's sake, refactor 2d molecule logic.
* [ ] Document everything.
* [ ] Add proper .csv databases.
* [ ] Add references (bibliography) for stuff like the databases. Mendeleev might be useful for this.
* [ ] Type the functions.
* [ ] Create a proper TODO tree.
* [ ] Solve the H problem like in HO or NH. There is a simple implementation now but not good at it's job.
* [ ] An example gallery to show molnim capabilities.

# Features that would be cool to implement

Here are listed features that would be cool to implement, don't seem to hard to do but also they are not explicitly necessary for the project. Some of them might seem pretty necessary, but if there is a workaround solving the issue, they are not a priority like the list above. That being said, I will probably develop something from this instead of doing the necessary stuff before.

* [ ] Actual atom numbering. At this moment we are simply numbering using the order from the .mol file, but might be good to be able to show actual numbering without working too hard. (See cannonicalization from [this](https://pubs.acs.org/doi/10.1021/acs.jcim.5b00543)
* [ ] Support other formats. Probably something like SMILES will be the next step to improve molnim. Probably the best aproach would be create a custom internal format. When parsing a format we transform to that internal format and then we can create the molecules from it.
* [ ] Solve the double bond issue. Now, when drawing a double bond, the bond is drawn in a direction defined by the mol file. That means we can draw a benzene ring with all the double bonds outside the ring, which is ugly af. I need to check or come up with an algorithm that solves that issue.
* [ ] Add functional groups automatic recongition. Check [this paper](https://jcheminf.biomedcentral.com/articles/10.1186/s13321-017-0225-z). It would be really nice to add this feature.
* [ ] Add reaction diagrams. While this might be unnecessary, I think adding a class that given some reactants, some products, reaction conditions and arrow that automates the creation creation and animation of reaction can simplify a lot of work.
* [ ] Use graph objects from manim. Probably this can save a ton of work done "manually" in this library, but it is working at the moment.
* [ ] Add a database for a lot of properties.
* [ ] Add pre-built in molecules.
* [ ] Enable create bonds between two different molecules.

# Epic features that probably won't be developed but it's good to keep in mind

Here I include feature that would be amazing to have but look to difficult or expensive to perform. If I find a way to do it I might promote a feature to the "would be cool to implement" group. They represent the least priority.

* [ ] Molecular orbitals. They are cool, but looks like I would need a few weeks of research and probably calculations would take forever. If someone gives me a hint on how to do this easily this probably will get promoted.
* [ ] 3D structure optimization. Having tools like ChemSketch looks like a useless feature but developing it sounds funny.
* [ ] Calculations based on .cif and .xyl files. Again, this looks funny but software like Mercury already does this for me.

==> manim-chemistry-0.1.1.tar.gz: manim-chemistry-0.1.1/TODO.md <==
# Necessary development to make this a decent work

This lists things that should be added in the near future to make this library useful and not just a random piece of garbage. Probably will grow with the project.

* [ ] Improve molecule creation.
* [ ] 2d atom should use element as a basis like 3d atom does.
* [ ] 3d should be separate files like 2d.
* [ ] Create actual code for the 3d bonds and not simply use the yoinked logic.
* [ ] Use a base class for both 2d and 3d and then add functionality. In the end, the main differences are the used objects.
* [ ] Add an option for coloring to 2d molecules (right after using element for 2d atoms this can be easily implemented).
* [ ] For God's sake, refactor 2d molecule logic.
* [ ] Document everything.
* [ ] Add proper .csv databases.
* [ ] Add references (bibliography) for stuff like the databases. Mendeleev might be useful for this.
* [ ] Type the functions.
* [ ] Create a proper TODO tree.
* [ ] Solve the H problem like in HO or NH. There is a simple implementation now but not good at it's job.
* [ ] An example gallery to show molnim capabilities.

# Features that would be cool to implement

Here are listed features that would be cool to implement, don't seem to hard to do but also they are not explicitly necessary for the project. Some of them might seem pretty necessary, but if there is a workaround solving the issue, they are not a priority like the list above. That being said, I will probably develop something from this instead of doing the necessary stuff before.

* [ ] Actual atom numbering. At this moment we are simply numbering using the order from the .mol file, but might be good to be able to show actual numbering without working too hard. (See cannonicalization from [this](https://pubs.acs.org/doi/10.1021/acs.jcim.5b00543))
* [ ] Support other formats. Probably something like SMILES will be the next step to improve molnim. Probably the best aproach would be create a custom internal format. When parsing a format we transform to that internal format and then we can create the molecules from it.
* [ ] Solve the double bond issue. Now, when drawing a double bond, the bond is drawn in a direction defined by the mol file. That means we can draw a benzene ring with all the double bonds outside the ring, which is ugly af. I need to check or come up with an algorithm that solves that issue.
* [ ] Add functional groups automatic recongition. Check [this paper](https://jcheminf.biomedcentral.com/articles/10.1186/s13321-017-0225-z). It would be really nice to add this feature.
* [ ] Add reaction diagrams. While this might be unnecessary, I think adding a class that given some reactants, some products, reaction conditions and arrow that automates the creation creation and animation of reaction can simplify a lot of work.
* [ ] Use graph objects from manim. Probably this can save a ton of work done "manually" in this library, but it is working at the moment.
* [ ] Add a database for a lot of properties.
* [ ] Add pre-built in molecules.
* [ ] Enable create bonds between two different molecules.

# Epic features that probably won't be developed but it's good to keep in mind

Here I include feature that would be amazing to have but look to difficult or expensive to perform. If I find a way to do it I might promote a feature to the "would be cool to implement" group. They represent the least priority.

* [ ] Molecular orbitals. They are cool, but looks like I would need a few weeks of research and probably calculations would take forever. If someone gives me a hint on how to do this easily this probably will get promoted.
* [ ] 3D structure optimization. Having tools like ChemSketch looks like a useless feature but developing it sounds funny.
* [ ] Calculations based on .cif and .xyl files. Again, this looks funny but software like Mercury already does this for me.
